#!/bin/sh
#=========================================================================
#
# CIOS udev hotplug event(Linux)
# Copyright Fujitsu Limited 2007-2011
#
#=========================================================================
# 20070205 new
# 20070220 RHEL5 hotplug2
# 20100921 checking keyword changed for scsi
# 20110111 added USB check for scsi
#=========================================================================
# $Name: SLINPSA-2_7_0-1 $
#=========================================================================

# If your system needs more time to make device data after the hotplug 
# event occured, please delete the "#" of the next line.
#sleep 30

PSAPATH=/var/lock/subsys/y30FJSVpsa
HPPATH=/var/opt/FJSVpsa/cios/hpdata/
SUBSYSTEM=$1
DEVPATH=$2
ACTION=$3

#========================================================================
# make_pci_file()
# outline
#   make pci hotplug file for cios
#
# parameter
#
# return value
#   0:OK 1:NG
#========================================================================
make_pci_file(){
	#check $DEVPATH format
	echo $DEVPATH | grep "^[[:xdigit:]]\{4\}:[[:xdigit:]]\{2\}:[[:xdigit:]]\{2\}\\.[[:digit:]]*$" > /dev/null
	if [ $? -ne 0 ] ; then
		logger -t FJSVpsa -s "W 06298 cios pci hotplug event PCI_SLOT_NAME doesn't correct. data: $DEVPATH"
		return 1
	fi

	#touch file
	filename=$HPPATH"/"$SUBSYSTEM"/"$DEVPATH-`date +%s.%N`-$ACTION
	touch $filename
	if [ $? -ne 0 ] ; then
		return 1
	fi

	return 0
}

#========================================================================
# make_scsi_file()
# outline
#   make scsi hotplug file for cios
#
# parameter
#
# return value
#   0:OK 1:NG
#========================================================================
make_scsi_file(){
	# check whether the device is the target of hotplug
	echo $DEVPATH | grep "usb" > /dev/null
	if [ $? -eq 0 ] ; then
		# no logs are written
		return 1
	fi

	#check $DEVPATH format
	echo $DEVPATH | grep "host" > /dev/null
	if [ $? -ne 0 ] ; then
		logger -t FJSVpsa -s "W 06298 cios scsi hotplug event DEVPATH doesn't correct. data: $DEVPATH"
		return 1
	fi

	#touch file
	hoge="`echo $DEVPATH | tr \/ \*`"
# 20070220 RHEL5 hotplug2
	filename=$HPPATH"/"$SUBSYSTEM"/"$hoge---`date +%s.%N`---$ACTION
# 20070220
	touch $filename
	if [ $? -ne 0 ] ; then
		return 1
	fi

	return 0
}

#========================================================================
# main()
# outline
#   make pci or scsi hotplug file for cios
#
# parameter
#	$1:"pci" or "scsi"
#	$2:"PCI_SLOT_NAME" for pci or "DEVPATH" for scsi
#	$3:action "add" or "remove"
#
# return value
#   0:OK 1:NG
#========================================================================
# check PSA is or not
if [ ! -e $PSAPATH ] ; then
	exit 1
fi

# check number of parameter
if [ $# -ne 3 ] ; then
	exit 1
fi

# check action format
if [ $ACTION != add -a $ACTION != remove  ] ; then
	logger -t FJSVpsa -s "W 06297 cios hotplug $SUBSYSTEM event ACTION hasn't set."
	exit 1
fi

# call file make function
if [ $SUBSYSTEM == "pci" ] ; then
	make_pci_file
elif [ $SUBSYSTEM == "scsi" ] ; then
	make_scsi_file
else
	logger -t FJSVpsa -s "W 06297 cios hotplug $SUBSYSTEM event SUBSYSTEM hasn't set."
	exit 1
fi

# check file make fucntion
if [ $? -ne 0 ] ; then
	exit 1
fi

exit 0

